@@ -475,7 +475,15 @@ class ISCSIConnector(InitiatorConnector):
 
     def _get_target_portals_from_iscsiadm_output(self, output):
         # return both portals and iqns
-        return [line.split() for line in output.splitlines()]
+        #
+        # as we are parsing a command line utility, allow for the
+        # possibility that additional debug data is spewed in the
+        # stream, and only grab actual ip / iqn lines.
+        targets = []
+        for data in [line.split() for line in output.splitlines()]:
+            if len(data) == 2 and data[1].startswith('iqn.'):
+                targets.append(data)
+        return targets
 
     def _disconnect_volume_multipath_iscsi(self, connection_properties,
                                            multipath_name):
